# rmtoo

NAME
SYNOPSIS
DESCRIPTION
OPTIONS
DEPRECATED OPTIONS
ENVIRONMENT
RETURN
SEE ALSO
LIMITATIONS
AUTHOR
COPYRIGHT

## NAME

rmtoo - requirements management tool

## SYNOPSIS

rmtoo [-h] -j file://cfgfile.json [-j file://cfgfile.json] [-j cfgoption] -y file://cfgfile.yaml [-y file://cfgfile.yaml]

## DESCRIPTION

The rmtoo is a requirment management tool. It understand long and short command line options. For a detailed functional description see rmtoo(7).

## OPTIONS

JSON and YAML can be intermixed. They are strictly evaluated from left to right.
-h, --help

Display a short usage help.

-j file://json_file, -j json_expr

Any number of JSON configuration files or JSON expression. The evaluation will be from left to right. Duplicated values are overwritten.

-y file://yaml_file

Any number of YAML configuration files. The evaluation will be from left to right. Duplicated values are overwritten.

## DEPRECATED OPTIONS

The following options do still exists because of compatibility reasons. They should not used in new projects. These options will be supported only until 31. 12. 2017.
-f CONFIG_FILE, --file-config=CONFIG_FILE

The directory with the requirements files.

-m MODULES_DIRECTORY, --modules-directory=MODULES_DIRECTORY

The directory where the rmtoo modules can be found. When the program was installed by standard system routines (e.g. as a deb or a rpm package) this option is not necessary. When using rmtoo from the repository or from a release tar ball this must point to the main directory.

-c MAKEFILE_DEPS, --create-makefile-dependencies=MAKEFILE_DEPS

For handling the invocation of rmtoo with the help of a Makefile, make itself must know the dependencies. When called with this option, rmtoo only creates the dependency file. The dependency depends also from the config file: when changing output artifacts of curse the dependencies change.

## ENVIRONMENT

When using the packages (e.g. deb) the system environment must be set up in the way that rmtoo can immediately be used. When using other ways (e.g. downloading the sources or using the tar file), the PYTHONPATH must be set. This must be set to the directory which contains the rmtoo directory which contains e.g. the lib and modules directory. In the tar file and the sources there is a file called setenv.sh which does exactly the right thing.

## RETURN

rmtoo returns 0 when all commands are successfully completed and a value not equal 0 when there was a problem.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## LIMITATIONS

Currently the makefile dependency creation are a best effort. It should work in mostly all times, but there are situations where not all dependencies are tracked - especially when adding new requirement files.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010,2017 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later